@@ -12,12 +12,23 @@ class ACRCommandsLoader(AzCommandsLoader):
 
     def __init__(self, cli_ctx=None):
         from azure.cli.core.profiles import ResourceType
-        super(ACRCommandsLoader, self).__init__(cli_ctx=cli_ctx,
-                                                resource_type=ResourceType.MGMT_CONTAINERREGISTRY,
-                                                operation_group='webhooks')
+        super().__init__(cli_ctx=cli_ctx,
+                         resource_type=ResourceType.MGMT_CONTAINERREGISTRY,
+                         operation_group='webhooks')
 
     def load_command_table(self, args):
         from azure.cli.command_modules.acr.commands import load_command_table
+        from azure.cli.core.aaz import load_aaz_command_table
+        try:
+            from . import aaz
+        except ImportError:
+            aaz = None
+        if aaz:
+            load_aaz_command_table(
+                loader=self,
+                aaz_pkg_name=aaz.__name__,
+                args=args
+            )
         load_command_table(self, args)
         return self.command_table
 
