@@ -18,7 +18,7 @@ from knack.log import get_logger
 
 logger = get_logger(__name__)
 
-WINDOWS_ASP_LOCATION_WEBAPP = 'northeurope'
+WINDOWS_ASP_LOCATION_WEBAPP = 'westeurope'
 STAGE1_ASP_LOCATION_WEBAPP = 'eastasia'
 WINDOWS_ASP_LOCATION_FUNCTIONAPP = 'francecentral'
 LINUX_ASP_LOCATION_WEBAPP = 'eastus2'
