@@ -2,7 +2,6 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
-# pylint: disable=unused-import
 
 from azure.cli.core import AzCommandsLoader
 
@@ -15,9 +14,9 @@ class DataLakeStoreCommandsLoader(AzCommandsLoader):
         from azure.cli.core.commands import CliCommandType
         from azure.cli.core.profiles import ResourceType
         dls_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.dls.custom#{}')
-        super(DataLakeStoreCommandsLoader, self).__init__(cli_ctx=cli_ctx,
-                                                          resource_type=ResourceType.MGMT_DATALAKE_STORE,
-                                                          custom_command_type=dls_custom)
+        super().__init__(cli_ctx=cli_ctx,
+                         resource_type=ResourceType.MGMT_DATALAKE_STORE,
+                         custom_command_type=dls_custom)
 
     def load_command_table(self, args):
         from azure.cli.command_modules.dls.commands import load_command_table
