@@ -26,8 +26,8 @@ class EHNamespaceCURDScenarioTest(ScenarioTest):
             'namespacename': self.create_random_name(prefix='eventhubs-nscli', length=20),
             'namespacename1': self.create_random_name(prefix='eventhubs-nscli', length=20),
             'namespacenamekafka': self.create_random_name(prefix='eventhubs-nscli1', length=20),
-            'tags': {'tag1=value1'},
-            'tags2': {'tag2=value2'},
+            'tags': 'tag1=value1',
+            'tags2': 'tag2=value2',
             'sku': 'Standard',
             'tier': 'Standard',
             'authoname': self.create_random_name(prefix='cliAutho', length=20),
