@@ -72,7 +72,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('certificate_subject_name', options_list=['--certificate-subject-name', '--cert-subject-name'], help='The subject name of the certificate to be created.')
         c.argument('vault_resource_group_name', options_list=['--vault-rg', c.deprecate(target='--vault-resource-group', redirect='--vault-rg', hide=True)],
                    help='Key vault resource group name, if not given it will be cluster resource group name')
-        c.argument('vault_name', help='Azure key vault name, it not given it will be the cluster resource group name')
+        c.argument('vault_name', help='Azure key vault name, if not given it will be the cluster resource group name')
         c.argument('cluster_size', options_list=['--cluster-size', '-s'], help='The number of nodes in the cluster. Default are 5 nodes')
         c.argument('vm_sku', help='VM Sku')
         c.argument('vm_user_name', help='The user name for logging to Vm. Default will be adminuser')
@@ -140,7 +140,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
     with self.argument_context('sf cluster setting set') as c:
         c.argument('settings_section_description', options_list=['--settings-section-description', '--settings-section'], type=get_json_object,
                    help='JSON encoded parameters configuration. Use @{file} to load from a file. '
-                        'For example: [{"section": "NamingService","parameter": "MaxOperationTimeout","value": 1000},{"section": "MaxFileOperationTimeout","parameter": "Max2","value": 1000]')
+                        'For example: [{"section": "NamingService","parameter": "MaxOperationTimeout","value": 1000},{"section": "MaxFileOperationTimeout","parameter": "Max2","value": 1000}]')
 
     with self.argument_context('sf cluster setting remove') as c:
         c.argument('settings_section_description', options_list=['--settings-section-description', '--settings-section'], type=get_json_object,
@@ -178,11 +178,11 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('maximum_nodes', arg_type=maximum_nodes)
         c.argument('force_restart', arg_type=get_three_state_flag(),
                    help='Indicates that the service host restarts even if the upgrade is a configuration-only change.')
-        c.argument('service_type_health_policy_map', options_list=['--service-type-health-policy-map', '--service-type-policy'],
+        c.argument('service_type_health_policy_map', options_list=['--service-type-health-policy-map'],
                    help='Specify the map of the health policy to use for different service types as a hash table in the following format: {\"ServiceTypeName\" : \"MaxPercentUnhealthyPartitionsPerService,MaxPercentUnhealthyReplicasPerPartition,MaxPercentUnhealthyServices\"}. For example: @{ \"ServiceTypeName01\" = \"5,10,5\"; \"ServiceTypeName02\" = \"5,5,5\" }')
 
     with self.argument_context('sf application update', arg_group='Upgrade description') as c:
-        c.argument('upgrade_replica_set_check_timeout', options_list=['--upgrade-replica-set-check-timeout', '--replica-check-timeout', '--rep-check-timeout'],
+        c.argument('upgrade_replica_set_check_timeout', options_list=['--replica-check-timeout', '--rep-check-timeout'],
                    help='Specify the maximum time, in seconds, that Service Fabric waits for a service to reconfigure into a safe state, if not already in a safe state, before Service Fabric proceeds with the upgrade.')
         c.argument('failure_action', arg_type=get_enum_type(['Rollback', 'Manual']),
                    help='Specify the action to take if the monitored upgrade fails. The acceptable values for this parameter are Rollback or Manual.')
@@ -198,14 +198,14 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                    help='Specify the maximum time, in seconds, that Service Fabric takes for the entire upgrade. After this period, the upgrade fails.')
         c.argument('consider_warning_as_error', options_list=['--warning-as-error', '--consider-warning-as-error'], arg_type=get_three_state_flag(),
                    help='Indicates whether to treat a warning health event as an error event during health evaluation.')
-        c.argument('default_service_type_max_percent_unhealthy_partitions_per_service', options_list=['--max-porcent-unhealthy-partitions', '--max-unhealthy-parts'],
-                   help='Specify the maximum percent of unhelthy partitions per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are form 0 to 100.')
-        c.argument('default_service_type_max_percent_unhealthy_replicas_per_partition', options_list=['--max-porcent-unhealthy-replicas', '--max-unhealthy-reps'],
-                   help='Specify the maximum percent of unhelthy replicas per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are form 0 to 100.')
-        c.argument('default_service_type_max_percent_unhealthy_services', options_list=['--max-porcent-unhealthy-services', '--max-unhealthy-servs'],
-                   help='Specify the maximum percent of unhelthy services allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are form 0 to 100.')
-        c.argument('max_percent_unhealthy_deployed_applications', options_list=['--max-porcent-unhealthy-apps', '--max-unhealthy-apps'],
-                   help='Specify the maximum percentage of the application instances deployed on the nodes in the cluster that have a health state of error before the application health state for the cluster is error. Allowed values are form 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_partitions_per_service', options_list=['--max-unhealthy-parts'],
+                   help='Specify the maximum percent of unhealthy partitions per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_replicas_per_partition', options_list=['--max-unhealthy-reps'],
+                   help='Specify the maximum percent of unhealthy replicas per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_services', options_list=['--max-unhealthy-servs'],
+                   help='Specify the maximum percent of unhealthy services allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are form 0 to 100.')
+        c.argument('max_percent_unhealthy_deployed_applications', options_list=['--max-unhealthy-apps'],
+                   help='Specify the maximum percentage of the application instances deployed on the nodes in the cluster that have a health state of error before the application health state for the cluster is error. Allowed values are from 0 to 100.')
 
     with self.argument_context('sf application create', validator=validate_create_application) as c:
         c.argument('application_type_name', options_list=['--type-name', '--application-type-name'], help='Specify the application type name.')
@@ -288,8 +288,12 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('protocol', arg_type=get_enum_type(['tcp', 'https', 'http', 'udp', 'icmp', 'ah', 'esp', 'any']), help='Network protocol')
         c.argument('source_port_ranges', nargs='+', help='A single or space separated list of source port ranges')
         c.argument('dest_port_ranges', nargs='+', help='A single or space separated list of destination port ranges')
+        c.argument('source_port_range', help='The source port or range. Integer or range between 0 and 65535. Asterisk \'*\' can also be used to match all ports.')
+        c.argument('dest_port_range', help='The destination port or range. Integer or range between 0 and 65535. Asterisk \'*\' can also be used to match all ports.')
         c.argument('source_addr_prefixes', nargs='+', help='The CIDR or source IP ranges. A single or space separated list of source address prefixes')
         c.argument('dest_addr_prefixes', nargs='+', help='CIDR or destination IP ranges. A single or space separated list of destination address prefixes')
+        c.argument('source_addr_prefix', help='The CIDR or source IP range. Asterisk \'*\' can also be used to match all source IPs. Default tags such as \'VirtualNetwork\', \'AzureLoadBalancer\' and \'Internet\' can also be used. If this is an ingress rule, specifies where network traffic originates from.')
+        c.argument('dest_addr_prefix', help='The destination address prefix. CIDR or destination IP range. Asterisk \'*\' can also be used to match all source IPs. Default tags such as \'VirtualNetwork\', \'AzureLoadBalancer\' and \'Internet\' can also be used.')
 
     # managed node type
     capacity = CLIArgumentType(
@@ -308,13 +312,15 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
 
     with self.argument_context('sf managed-node-type') as c:
         c.argument('node_type_name', options_list=['-n', '--name', '--node-type-name'], help='node type name.')
-        c.argument('instance_count', help='essage = "The number of nodes in the node type.')
+
+    with self.argument_context('sf managed-node-type create') as c:
+        c.argument('instance_count', help='"The number of nodes in the node type.')
         c.argument('primary', arg_type=get_three_state_flag(), help='Specify if the node type is primary. On this node type will run system services. Only one node type should be marked as primary. Primary node type cannot be deleted or changed for existing clusters.')
         c.argument('disk_size', type=int, options_list=['--disk-size', '--data-disk-size'], help='Disk size for each vm in the node type in GBs.', default=100)
         c.argument('disk_type', arg_type=get_enum_type(DiskType), options_list=['--disk-type', '--data-disk-type'],
-                   help='Managed data disk type. IOPS and throughput are given by the disk size, to see more information go to https://learn.microsoft.com/azure/virtual-machines/disks-types. Default StandardSSD_LRS'
-                   'Standard_LRS: Standard HDD locally redundant storage. Best for backup, non-critical, and infrequent access.'
-                   'StandardSSD_LRS: Standard SSD locally redundant storage. Best for web servers, lightly used enterprise applications and dev/test.'
+                   help='Managed data disk type. IOPS and throughput are given by the disk size. To see more information, go to https://learn.microsoft.com/azure/virtual-machines/disks-types. Default: StandardSSD_LRS. '
+                   'Standard_LRS: Standard HDD locally redundant storage. Best for backup, non-critical, and infrequent access. '
+                   'StandardSSD_LRS: Standard SSD locally redundant storage. Best for web servers, lightly used enterprise applications and dev/test. '
                    'Premium_LRS: Premium SSD locally redundant storage. Best for production and performance sensitive workloads.')
         c.argument('application_start_port', options_list=['--application-start-port', '--app-start-port'], help='Application start port of a range of ports.')
         c.argument('application_end_port', options_list=['--application-end-port', '--app-end-port'], help='Application End port of a range of ports.')
@@ -330,6 +336,18 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('is_stateless', arg_type=get_three_state_flag(), help='Indicates if the node type can only host Stateless workloads.', default=False)
         c.argument('multiple_placement_groups', options_list=['--multiple-placement-groups', '--multi-place-groups'], arg_type=get_three_state_flag(),
                    help='Indicates if scale set associated with the node type can be composed of multiple placement groups.', default=False)
+        c.argument('tags', arg_type=tags_type)
+
+    with self.argument_context('sf managed-node-type update') as c:
+        c.argument('instance_count', help='"The number of nodes in the node type.')
+        c.argument('application_start_port', options_list=['--application-start-port', '--app-start-port'], help='Application start port of a range of ports.')
+        c.argument('application_end_port', options_list=['--application-end-port', '--app-end-port'], help='Application End port of a range of ports.')
+        c.argument('ephemeral_start_port', help='Ephemeral start port of a range of ports.')
+        c.argument('ephemeral_end_port', help='Ephemeral end port of a range of ports.')
+        c.argument('vm_size', help='The size of virtual machines in the pool. All virtual machines in a pool are the same size.')
+        c.argument('capacity', arg_type=capacity)
+        c.argument('placement_property', arg_type=placement_property)
+        c.argument('tags', arg_type=tags_type)
 
     with self.argument_context('sf managed-node-type node') as c:
         c.argument('node_name', nargs='+', help='list of target nodes to perform the operation.')
@@ -364,7 +382,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
 
     # managed-application
     service_type_health_policy_map = CLIArgumentType(
-        options_list=['--service-type-health-policy-map', '--service-type-policy'],
+        options_list=['--service-type-health-policy-map'],
         action=AddServiceTypeHealthPolicyAction,
         nargs='*',
         help='Specify the map of the health policy to use for different service types as key/value pairs in the following format: \"ServiceTypeName\"=\"MaxPercentUnhealthyPartitionsPerService,MaxPercentUnhealthyReplicasPerPartition,MaxPercentUnhealthyServices\". '
@@ -383,9 +401,9 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                    help='Indicates that the service host restarts even if the upgrade is a configuration-only change.')
         c.argument('recreate_application', arg_type=get_three_state_flag(),
                    help='Determines whether the application should be recreated on update. If value=true, the rest of the upgrade policy parameters are not allowed.')
-        c.argument('upgrade_replica_set_check_timeout', options_list=['--upgrade-replica-set-check-timeout', '--replica-check-timeout', '--rep-check-timeout'],
+        c.argument('upgrade_replica_set_check_timeout', options_list=['--replica-check-timeout', '--rep-check-timeout'],
                    help='Specify the maximum time, in seconds, that Service Fabric waits for a service to reconfigure into a safe state, if not already in a safe state, before Service Fabric proceeds with the upgrade.')
-        c.argument('instance_close_delay_duration', options_list=['--instance-close-delay-duration', '--instance-close-duration', '--close-duration'],
+        c.argument('instance_close_delay_duration', options_list=['--instance-close-delay-duration'],
                    help='Specify the duration in seconds, to wait before a stateless instance is closed, to allow the active requests to drain gracefully. This would be effective when the instance is closing during the application/cluster upgrade, only for those instances which have a non-zero delay duration configured in the service description.')
         c.argument('failure_action', arg_type=get_enum_type(FailureAction),
                    help='Specify the action to take if the monitored upgrade fails. The acceptable values for this parameter are Rollback or Manual.')
@@ -401,17 +419,17 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                    help='Specify the maximum time, in seconds, that Service Fabric takes to upgrade a single upgrade domain. After this period, the upgrade fails.')
         c.argument('upgrade_timeout',
                    help='Specify the maximum time, in seconds, that Service Fabric takes for the entire upgrade. After this period, the upgrade fails.')
-        c.argument('consider_warning_as_error', options_list=['--warning-as-error', '--consider-warning-as-error'], arg_type=get_three_state_flag(),
+        c.argument('consider_warning_as_error', options_list=['--warning-as-error'], arg_type=get_three_state_flag(),
                    help='Indicates whether to treat a warning health event as an error event during health evaluation.')
-        c.argument('default_service_type_max_percent_unhealthy_partitions_per_service', options_list=['--max-percent-unhealthy-partitions', '--max-unhealthy-parts'],
-                   help='Specify the maximum percent of unhelthy partitions per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
-        c.argument('default_service_type_max_percent_unhealthy_replicas_per_partition', options_list=['--max-percent-unhealthy-replicas', '--max-unhealthy-reps'],
-                   help='Specify the maximum percent of unhelthy replicas per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
-        c.argument('default_service_type_max_percent_unhealthy_services', options_list=['--max-percent-unhealthy-services', '--max-unhealthy-servs'],
-                   help='Specify the maximum percent of unhelthy services allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_partitions_per_service', options_list=['--max-unhealthy-parts'],
+                   help='Specify the maximum percent of unhealthy partitions per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_replicas_per_partition', options_list=['--max-unhealthy-reps'],
+                   help='Specify the maximum percent of unhealthy replicas per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
+        c.argument('default_service_type_max_percent_unhealthy_services', options_list=['--max-unhealthy-servs'],
+                   help='Specify the maximum percent of unhealthy services allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.')
         c.argument('service_type_health_policy_map', arg_type=service_type_health_policy_map)
-        c.argument('max_percent_unhealthy_deployed_applications', options_list=['--max-percent-unhealthy-deployed-applications', '--max-percent-unhealthy-apps', '--max-unhealthy-apps'],
-                   help='Specify the maximum percentage of the application instances deployed on the nodes in the cluster that have a health state of error before the application health state for the cluster is error. Allowed values are form 0 to 100.')
+        c.argument('max_percent_unhealthy_deployed_applications', options_list=['--max-unhealthy-apps'],
+                   help='Specify the maximum percentage of the application instances deployed on the nodes in the cluster that have a health state of error before the application health state for the cluster is error. Allowed values are from 0 to 100.')
 
     with self.argument_context('sf managed-application create', validator=validate_create_managed_application) as c:
         c.argument('application_type_name', options_list=['--type-name', '--application-type-name'], help='Specify the application type name.')
@@ -421,7 +439,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
 
     # managed-service
     partition_names = CLIArgumentType(
-        nards="+",
+        nargs='+',
         help='Specify the array for the names of the partitions. This is only used with Named partition scheme.')
 
     with self.argument_context('sf managed-service') as c:
@@ -477,7 +495,7 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
         c.argument('default_move_cost', arg_type=get_enum_type(MoveCost),
                    help='Specify the default cost for a move. Higher costs make it less likely that the Cluster Resource Manager will move the replica when trying to balance the cluster.')
         c.argument('placement_constraints',
-                   help='Specify the placement constraints as a string. Placement constraints are boolean expressions on node properties and allow for restricting a service to particular nodes based on the service requirements. For example, to place a service on nodes where NodeType is blue specify the following: \"NodeColor == blue)\".')
+                   help='Specify the placement constraints as a string. Placement constraints are boolean expressions on node properties and allow for restricting a service to particular nodes based on the service requirements. For example, to place a service on nodes where NodeType is blue specify the following: \"(NodeColor == blue)\".')
         # Stateful arguments
         c.argument('min_replica_set_size', options_list=['--min-replica-set-size', '--min-replica'], help='Specify the min replica set size for the stateful service.')
         c.argument('target_replica_set_size', options_list=['--target-replica-set-size', '--target-replica'], help='Specify the target replica set size for the stateful service.')
