@@ -12,7 +12,7 @@ class UtilCommandsLoader(AzCommandsLoader):
     def __init__(self, cli_ctx=None):
         from azure.cli.core.commands import CliCommandType
         util_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.util.custom#{}')
-        super(UtilCommandsLoader, self).__init__(cli_ctx=cli_ctx, custom_command_type=util_custom)
+        super().__init__(cli_ctx=cli_ctx, custom_command_type=util_custom)
 
     def load_command_table(self, args):
         from azure.cli.command_modules.util.commands import load_command_table
