@@ -133,7 +133,7 @@ def list_sku_info(cli_ctx, location=None):
 
 
 # pylint: disable=line-too-long
-def is_sku_available(cmd, sku_info, zone):
+def is_sku_available(sku_info, zone):
     """
     The SKU is unavailable in the following cases:
     1. regional restriction and the region is restricted
@@ -146,16 +146,12 @@ def is_sku_available(cmd, sku_info, zone):
     if not sku_info.get('restrictions', []):
         return is_available
     for restriction in sku_info['restrictions']:
-        if restriction.get('reason_code', '') == 'NotAvailableForSubscription':
-            # The attribute location_info is not supported in versions 2017-03-30 and earlier
-            if cmd.supported_api_version(max_api='2017-03-30'):
-                is_available = False
-                break
+        if restriction.get('reasonCode', '') == 'NotAvailableForSubscription':
             if restriction['type'] == 'Zone' and not (
-                    set(sku_info['location_info'][0].get('zones', []) or []) - set(restriction['restriction_info'].get('zones', []) or [])):
+                    set(sku_info['locationInfo'][0].get('zones', []) or []) - set(restriction['restrictionInfo'].get('zones', []) or [])):
                 is_restrict_zone = True
             if restriction['type'] == 'Location' and (
-                    sku_info['location_info'][0]['location'] in (restriction['restriction_info'].get('locations', []) or [])):
+                    sku_info['locationInfo'][0]['location'] in (restriction['restrictionInfo'].get('locations', []) or [])):
                 is_restrict_location = True
 
             if is_restrict_location or (is_restrict_zone and zone):
